%define major   1
%define libname %mklibname kolab %major

%define php_extdir %(php-config --extension-dir 2>/dev/null || echo %{_libdir}/php)
%{!?php_inidir: %global php_inidir %{_sysconfdir}/php.d/}

# Filter out private python and php libs. Does not work on EPEL5,
# therefor we use it conditionally
%{?filter_setup:
%filter_provides_in %{python2_sitearch}/.*\.so$
%filter_provides_in %{php_extdir}/.*\.so$
%filter_setup
}

Name:           libkolab
Version:        1.0.2
Release:        %mkrel 6
Summary:        Kolab Object Handling Library
Group:          System/Servers
License:        LGPLv3+
URL:            http://cgit.kolab.org/libkolab
Source0:        http://cgit.kolab.org/%{name}/snapshot/%{name}-%{version}.tar.gz
Patch1:         Q_DECL_IMPORT.patch
BuildRequires:  libcurl-devel
BuildRequires:  libkolabxml-devel >= 1.0
BuildRequires:  php-devel
BuildRequires:  pkgconfig(python2)
BuildRequires:  php-cli
BuildRequires:  swig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  cmake
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5Akonadi)
BuildRequires:  cmake(KF5Contacts)
BuildRequires:  cmake(KF5CalendarCore)
BuildRequires:  cmake(KF5CalendarUtils)
BuildRequires:  cmake(KF5Mime)
BuildRequires:  cmake(KF5AkonadiNotes)

%description
The libkolab library is an advanced library to  handle Kolab objects.

%package -n %{libname}
Summary:        Kolab Object Handling Library
Group:          System/Libraries 
Obsoletes:      %{name} < %version
%rename         %{_lib}kolab0

%description -n %{libname}
The libkolab library is an advanced library to handle Kolab objects.

%package devel
Summary:        Kolab library development headers
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       libkolabxml-devel >= 1.1.0

%description devel
Development headers for the Kolab object libraries.

%package -n php-kolab
Summary:        PHP Bindings for libkolab
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       php-kolabformat >= 1.0.0

%description -n php-kolab
PHP Bindings for libkolab.

%package -n python-kolab
Summary:        Python bindings for libkolab
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}
Requires:       python-kolabformat >= 1.0.0

%description -n python-kolab
Python bindings for libkolab.

%prep
%setup -q
%autopatch -p1

%build
%cmake_qt5 \
    -DQT5_BUILD=ON \
    -DINCLUDE_INSTALL_DIR=%{_includedir} \
    -DUSE_LIBCALENDARING=OFF \
    -DPHP_BINDINGS=ON \
    -DPHP_INSTALL_DIR=%{php_extdir} \
    -DPYTHON_BINDINGS=ON \
    -DPYTHON_INSTALL_DIR=%{python2_sitearch}

%make_build

%install
%make_install -C build

mkdir -p %{buildroot}%{_datadir}/php
mv %{buildroot}/%{php_extdir}/*.php %{buildroot}%{_datadir}/php/.

mkdir -p %{buildroot}/%{php_inidir}
cat >%{buildroot}/%{php_inidir}/kolab.ini <<EOF
extension=kolabcalendaring.so
extension=kolabicalendar.so
extension=kolabobject.so
extension=kolabshared.so
EOF

# Workaround for #2050
# We need to test first if needed for Mageia
#cat >%%{buildroot}/%%{php_inidir}/kolabdummy.ini <<EOF
#; Kolab libraries
#extension=dummy.so
#EOF

touch %{buildroot}%{python2_sitearch}/kolab/__init__.py


%check
pushd build/tests
./benchmarktest || :
./calendaringtest || :
./formattest || :
./freebusytest || :
./icalendartest || :
./kcalconversiontest || :
./upgradetest || :
popd

%files -n %{libname}
%{_libdir}/%{name}.so.%{major}
%{_libdir}/%{name}.so.%{major}.*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/cmake/Libkolab
%{_includedir}/kolab

%files -n php-kolab
%config(noreplace) %{php_inidir}/kolab.ini
%{_datadir}/php/kolabcalendaring.php
%{php_extdir}/kolabcalendaring.so
%{_datadir}/php/kolabicalendar.php
%{php_extdir}/kolabicalendar.so
%{_datadir}/php/kolabobject.php
%{php_extdir}/kolabobject.so
%{_datadir}/php/kolabshared.php
%{php_extdir}/kolabshared.so
%{_datadir}/php/dummy.php
%{php_extdir}/dummy.so

%files -n python-kolab
%{python2_sitearch}/kolab/__init__.py*
%{python2_sitearch}/kolab/_calendaring.so
%{python2_sitearch}/kolab/calendaring.py*
%{python2_sitearch}/kolab/_icalendar.so
%{python2_sitearch}/kolab/icalendar.py*
%{python2_sitearch}/kolab/_shared.so*
%{python2_sitearch}/kolab/shared.py*
%{python2_sitearch}/kolab/_kolabobject.so
%{python2_sitearch}/kolab/kolabobject.py*


%changelog
* Fri Sep 16 2016 daviddavid <daviddavid> 1.0.2-6.mga6
+ Revision: 1053495
- fix Kf5 BRs, kdepimlibs-devel is no more provided
- use new python macros

* Wed Mar 16 2016 spuhler <spuhler> 1.0.2-5.mga6
+ Revision: 992239
- rediffed Q_DECL_IMPORT.patch

* Tue Jan 26 2016 luigiwalser <luigiwalser> 1.0.2-4.mga6
+ Revision: 927867
- rebuild for libical

* Wed Jan 20 2016 spuhler <spuhler> 1.0.2-3.mga6
+ Revision: 926088
- reversed commit #917171
  * this package is useless w/o php-bindings
  * we now reverted to php-5.x

* Thu Dec 31 2015 neoclust <neoclust> 1.0.2-2.mga6
+ Revision: 917263
- Fix upgrade

* Thu Dec 31 2015 neoclust <neoclust> 1.0.2-1.mga6
+ Revision: 917171
- New version 1.0.2

  + tv <tv>
    - rebuild for new boost

  + daviddavid <daviddavid>
    - rebuild for new boost 1.59.0

  + spuhler <spuhler>
    - added Q_DECL_IMPORT patch
    - added Plasma5.patch
    - enabled QT5 build
    - upgrade to vers. 1.0.1

* Sun Aug 02 2015 daviddavid <daviddavid> 0.6.1-2.mga6
+ Revision: 860581
- rebuild for new boost-1.58.0

* Thu Jul 02 2015 spuhler <spuhler> 0.6.1-1.mga6
+ Revision: 849554
- upgrade to vers. 0.6.1
- deleting obsolete patch files

* Fri Nov 21 2014 spuhler <spuhler> 0.5.3-5.mga5
+ Revision: 798142
- rebuilt with new libkolabxml

* Wed Oct 15 2014 umeabot <umeabot> 0.5.3-4.mga5
+ Revision: 743884
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.5.3-3.mga5
+ Revision: 726725
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.5.3-2.mga5
+ Revision: 681560
- Mageia 5 Mass Rebuild

* Thu Aug 28 2014 spuhler <spuhler> 0.5.3-1.mga5
+ Revision: 668918
- upgrade to version 0.5.3

* Sun Jul 06 2014 spuhler <spuhler> 0.5.2-1.mga5
+ Revision: 644105
- upgrade to ver. 0.5.2

* Sat May 31 2014 pterjan <pterjan> 0.5.0-3.mga5
+ Revision: 628299
- Rebuild for new Python

* Fri May 02 2014 spuhler <spuhler> 0.5.0-2.mga5
+ Revision: 619378
- rebuild for php-5.6.0

* Mon Feb 24 2014 spuhler <spuhler> 0.5.0-1.mga5
+ Revision: 596700
- upgrade to ver 0.5.0

* Sat Jan 25 2014 oden <oden> 0.4.2-7.mga4
+ Revision: 568188
- revert version bump
- don't use parallel make

* Fri Jan 24 2014 oden <oden> 0.5.0-1.mga4
+ Revision: 568064
- 0.5.0

  + pterjan <pterjan>
    - Rebuild for new PHP

* Sat Oct 19 2013 umeabot <umeabot> 0.4.2-6.mga4
+ Revision: 531965
- Mageia 4 Mass Rebuild

* Mon Aug 05 2013 fwang <fwang> 0.4.2-5.mga4
+ Revision: 463709
- add fedora patch to fix build with recent ccmake

  + spuhler <spuhler>
    - bumped rel to rebuild agains new php-devel

* Thu May 09 2013 spuhler <spuhler> 0.4.2-4.mga3
+ Revision: 412790
- added missing lib to kolab.ini
 - kolabobject.so

* Sat Apr 27 2013 tmb <tmb> 0.4.2-3.mga3
+ Revision: 411443
- bump rel

* Fri Apr 26 2013 spuhler <spuhler> 0.4.2-2.mga3
+ Revision: 411195
- removed BuildRequires:  libcalendaring-devel
 - we have now the required kdepimlibs >4.9
 - these will replace libcalendaring
 - changed in cmake section -DUSE_LIBCALENDARING=On to OFF

* Tue Apr 23 2013 spuhler <spuhler> 0.4.2-1.mga3
+ Revision: 411023
- removed BuildRequires:  libcalendaring-devel
 -it's provided now by the kde libraries
 - upstream seems to drop it
 - this means security update will not be provided for this lib
- upgrade to version 0.4.2
 - fixes bugs
 - rebuild against newest kdelibs

* Sat Jan 12 2013 umeabot <umeabot> 0.4.1-2.mga3
+ Revision: 357617
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 spuhler <spuhler> 0.4.1-1.mga3
+ Revision: 344104
- added the two new files
  kolabobject.php
  kolabobject.so
- upgrade to 0.4.1
- upgrade to 0.4.0

* Thu Sep 20 2012 fwang <fwang> 0.3.2-2.mga3
+ Revision: 296272
- bump rel to upload

* Tue Sep 18 2012 spuhler <spuhler> 0.3.2-1.mga3
+ Revision: 295840
- patch1 removed
- upgrade to 0.3.2

* Sun Sep 16 2012 spuhler <spuhler> 0.3.1-3.mga3
+ Revision: 294635
- patch0 reactivated
- added BuildRequires:  libcalendaring-devel >= 4.9
  since we don't have kdepimlibs 4.10 for a while
  Updated the versions of the requires to upstream

  + fwang <fwang>
    - curl is of no use

* Sun Sep 09 2012 fwang <fwang> 0.3.1-2.mga3
+ Revision: 290899
- filter out undefined from linker flags
- we are building module now
- br swig
- requires kolabxml-devel
- fix linkage of php module
- cleanup spec and migrate to mageia pkgname

* Sat Aug 25 2012 spuhler <spuhler> 0.3.1-1.mga3
+ Revision: 283959
- imported package libkolab

